@@ -70,6 +70,7 @@ var annotated_dup =
     [ "pw_impl_module_events", "structpw__impl__module__events.html", "structpw__impl__module__events" ],
     [ "pw_impl_node", "structpw__impl__node.html", null ],
     [ "pw_impl_node_events", "structpw__impl__node__events.html", "structpw__impl__node__events" ],
+    [ "pw_impl_node_rt_events", "structpw__impl__node__rt__events.html", "structpw__impl__node__rt__events" ],
     [ "pw_impl_port", "structpw__impl__port.html", null ],
     [ "pw_impl_port_events", "structpw__impl__port__events.html", "structpw__impl__port__events" ],
     [ "pw_link", "structpw__link.html", null ],
@@ -275,6 +276,7 @@ var annotated_dup =
     [ "spa_poll_event", "structspa__poll__event.html", "structspa__poll__event" ],
     [ "spa_port_info", "structspa__port__info.html", "structspa__port__info" ],
     [ "spa_process_latency_info", "structspa__process__latency__info.html", "structspa__process__latency__info" ],
+    [ "spa_ratelimit", "structspa__ratelimit.html", "structspa__ratelimit" ],
     [ "spa_rectangle", "structspa__rectangle.html", "structspa__rectangle" ],
     [ "spa_region", "structspa__region.html", "structspa__region" ],
     [ "spa_result_device_params", "structspa__result__device__params.html", "structspa__result__device__params" ],
@@ -288,6 +290,7 @@ var annotated_dup =
     [ "spa_support", "structspa__support.html", "structspa__support" ],
     [ "spa_system", "structspa__system.html", "structspa__system" ],
     [ "spa_system_methods", "structspa__system__methods.html", "structspa__system__methods" ],
+    [ "spa_tag_info", "structspa__tag__info.html", "structspa__tag__info" ],
     [ "spa_thread", "structspa__thread.html", null ],
     [ "spa_thread_utils", "structspa__thread__utils.html", "structspa__thread__utils" ],
     [ "spa_thread_utils_methods", "structspa__thread__utils__methods.html", "structspa__thread__utils__methods" ],
