@@ -1,6 +1,6 @@
 var group__pw__context =
 [
-    [ "src/pipewire/context.h", "src_2pipewire_2context_8h.html", null ],
+    [ "context.h", "src_2pipewire_2context_8h.html", null ],
     [ "pw_context_events", "structpw__context__events.html", [
       [ "version", "structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c", null ],
       [ "destroy", "structpw__context__events.html#a34b60636aee5925696ca80cbbf63755e", null ],
