@@ -1,5 +1,27 @@
 var NAVTREEINDEX16 =
 {
+"page_dma_buf.html#autotoc_md300":[5,10,3],
+"page_dma_buf.html#autotoc_md301":[5,10,4],
+"page_examples.html":[7,7],
+"page_library.html":[5,9],
+"page_library.html#autotoc_md45":[5,9,0],
+"page_library.html#autotoc_md46":[5,9,1],
+"page_library.html#autotoc_md47":[5,9,2],
+"page_library.html#autotoc_md48":[5,9,3],
+"page_library.html#autotoc_md49":[5,9,3,0],
+"page_library.html#autotoc_md50":[5,9,3,1],
+"page_library.html#autotoc_md51":[5,9,3,2],
+"page_library.html#autotoc_md52":[5,9,3,3],
+"page_library.html#autotoc_md53":[5,9,3,4],
+"page_library.html#autotoc_md54":[5,9,3,5],
+"page_library.html#autotoc_md55":[5,9,3,6],
+"page_library.html#autotoc_md56":[5,9,3,7],
+"page_library.html#autotoc_md57":[5,9,3,8],
+"page_library.html#autotoc_md58":[5,9,3,9],
+"page_library.html#autotoc_md59":[5,9,4],
+"page_library.html#autotoc_md60":[5,9,4,0],
+"page_library.html#autotoc_md61":[5,9,4,1],
+"page_library.html#autotoc_md62":[5,9,5],
 "page_library.html#autotoc_md63":[5,9,6],
 "page_library.html#autotoc_md64":[5,9,7],
 "page_man_pipewire_1.html":[5,14,0],
@@ -227,27 +249,5 @@ var NAVTREEINDEX16 =
 "page_proxy.html#sec_page_proxy_destroy":[8,1,6],
 "page_proxy.html#sec_page_proxy_events":[8,1,5],
 "page_proxy.html#sec_page_proxy_methods":[8,1,4],
-"page_proxy.html#sec_page_proxy_overview":[8,1,0],
-"page_pulseaudio.html":[5,16],
-"page_pulseaudio.html#autotoc_md281":[5,16,0],
-"page_pulseaudio.html#autotoc_md282":[5,16,0,0],
-"page_pulseaudio.html#autotoc_md283":[5,16,0,1],
-"page_pulseaudio.html#autotoc_md284":[5,16,1],
-"page_pulseaudio.html#autotoc_md285":[5,16,1,0],
-"page_pulseaudio.html#autotoc_md286":[5,16,1,1],
-"page_pulseaudio.html#autotoc_md287":[5,16,1,2],
-"page_pulseaudio.html#autotoc_md288":[5,16,1,3],
-"page_pulseaudio.html#autotoc_md289":[5,16,2],
-"page_scheduling.html":[5,11],
-"page_scheduling.html#autotoc_md108":[5,11,0],
-"page_scheduling.html#autotoc_md109":[5,11,1],
-"page_scheduling.html#autotoc_md110":[5,11,2],
-"page_scheduling.html#autotoc_md111":[5,11,2,0],
-"page_scheduling.html#autotoc_md112":[5,11,2,1],
-"page_scheduling.html#autotoc_md113":[5,11,2,2],
-"page_scheduling.html#autotoc_md114":[5,11,3],
-"page_scheduling.html#autotoc_md115":[5,11,3,0],
-"page_session_manager.html":[5,15],
-"page_session_manager.html#autotoc_md65":[5,15,0],
-"page_session_manager.html#autotoc_md66":[5,15,1]
+"page_proxy.html#sec_page_proxy_overview":[8,1,0]
 };
