@@ -1,50 +1,71 @@
 var NAVTREEINDEX4 =
 {
-"group__pw__node.html#ga13f0cb22b45e8f81e709b84ff3b1fde7":[10,4,10,11],
-"group__pw__node.html#ga1977da2214d00db4a4d50202da3a2c35":[10,4,10,22],
-"group__pw__node.html#ga31e36ebfd9bbef91cea1381889a7cf83":[10,4,10,33],
-"group__pw__node.html#ga3add61d46ad7b1daa86792cbeafc6090":[10,4,10,21],
-"group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f":[10,4,10,27],
-"group__pw__node.html#ga3c78657690ffa3263238181bbe7073e4":[10,4,10,15],
-"group__pw__node.html#ga3db541c9ec1c2245fe17402135979f2d":[10,4,10,10],
-"group__pw__node.html#ga5437fe007ac346f48f0f63fec8ca8b40":[10,4,10,19],
-"group__pw__node.html#ga551b316bd8df6636cd863b82d3f006e3":[10,4,10,25],
-"group__pw__node.html#ga5768e66e04bfef45e468df3e38158c93":[10,4,10,26],
-"group__pw__node.html#ga593a4f2610442e1956052f5c13de02f2":[10,4,10,16],
-"group__pw__node.html#ga6ac60f95cc0fdb6d769df30cce34901c":[10,4,10,29],
-"group__pw__node.html#ga6b2101857ce7cd58fa7024afa281a730":[10,4,10,20],
-"group__pw__node.html#ga7f79a67df47a08661d622c1ca73571ea":[10,4,10,12],
-"group__pw__node.html#ga8f11f362e3c9cda9d9fba69ed37f9c9b":[10,4,10,24],
-"group__pw__node.html#ga91a6a1a257b75f8a6fd5eb6755447a59":[10,4,10,8],
-"group__pw__node.html#ga98ac2a3a420d51c2afe18a0e79c18efe":[10,4,10,32],
-"group__pw__node.html#ga9d39e0829f4a14185dc242d5c362b9de":[10,4,10,9],
-"group__pw__node.html#gabdc61213ac88ea6daf6141e0130d0430":[10,4,10,31],
-"group__pw__node.html#gac3a4cf514e46d1e590ad45fd3e8d7813":[10,4,10,13],
-"group__pw__node.html#gac493839c0b0a1d0b935969f2e990a2df":[10,4,10,30],
-"group__pw__node.html#gae34dde148d3ae268808d68926a8a2da4":[10,4,10,6],
-"group__pw__node.html#gaea23ddf2322c57e3cca4a7d40144bda8":[10,4,10,18],
-"group__pw__node.html#gaf8cda535f0a1e63b1074f859cf650525":[10,4,10,14],
-"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa316510257c8a6afc788c415cc3288ad2":[10,4,10,30,0],
-"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa715c586abce5cbbc09db32145a51e82f":[10,4,10,30,2],
-"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa801ee69d0b0c9d30b12ff89daae9a075":[10,4,10,30,3],
-"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa73a63afebf017a0c0afdea192b1691c":[10,4,10,30,1],
-"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa9c88f01497f82d9ffc4605dae27e93a":[10,4,10,30,4],
+"group__pw__module.html#ga9a9305a5898d1480d8a542f300743ed6":[10,4,9,8],
+"group__pw__module.html#ga9f006acecf3988802d7bd35600b3cfba":[10,4,9,15],
+"group__pw__module.html#gaaf5d15bb2ee832cc2beb1f0c2921ef8c":[10,4,9,9],
+"group__pw__module.html#gab095f436fa3ebb521f692fb6bf99c79f":[10,4,9,10],
+"group__pw__module.html#gab941c4159785bfa9cf253f9658b82d8f":[10,4,9,18],
+"group__pw__module.html#gacdc4ec9a184d0b9ed910cc927e868dc9":[10,4,9,6],
+"group__pw__module.html#gad670c8d581f68d016f475c12cff250c8":[10,4,9,12],
+"group__pw__module.html#gad6d3cbf77b94e229ef370635889b8121":[10,4,9,11],
+"group__pw__module.html#gae35020db0760ef496a5fbe14745fd56b":[10,4,9,13],
+"group__pw__node.html":[10,4,10],
+"group__pw__node.html#ga0093e032db467e20f79767260fa1758e":[10,4,10,24],
+"group__pw__node.html#ga027e0d76dfb4448a29d718bec066b409":[10,4,10,18],
+"group__pw__node.html#ga03964e24225bdf9a290590cd30ad664a":[10,4,10,29],
+"group__pw__node.html#ga0ee148738da978c59c3afaf91215db71":[10,4,10,35],
+"group__pw__node.html#ga111891241c623bdfe86ba5e1811f374e":[10,4,10,8],
+"group__pw__node.html#ga125b3c8bae9656635dd9c24febbe221f":[10,4,10,5],
+"group__pw__node.html#ga13f0cb22b45e8f81e709b84ff3b1fde7":[10,4,10,12],
+"group__pw__node.html#ga1977da2214d00db4a4d50202da3a2c35":[10,4,10,23],
+"group__pw__node.html#ga31e36ebfd9bbef91cea1381889a7cf83":[10,4,10,34],
+"group__pw__node.html#ga3add61d46ad7b1daa86792cbeafc6090":[10,4,10,22],
+"group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f":[10,4,10,28],
+"group__pw__node.html#ga3c78657690ffa3263238181bbe7073e4":[10,4,10,16],
+"group__pw__node.html#ga3db541c9ec1c2245fe17402135979f2d":[10,4,10,11],
+"group__pw__node.html#ga5437fe007ac346f48f0f63fec8ca8b40":[10,4,10,20],
+"group__pw__node.html#ga551b316bd8df6636cd863b82d3f006e3":[10,4,10,26],
+"group__pw__node.html#ga5768e66e04bfef45e468df3e38158c93":[10,4,10,27],
+"group__pw__node.html#ga593a4f2610442e1956052f5c13de02f2":[10,4,10,17],
+"group__pw__node.html#ga6ac60f95cc0fdb6d769df30cce34901c":[10,4,10,30],
+"group__pw__node.html#ga6b2101857ce7cd58fa7024afa281a730":[10,4,10,21],
+"group__pw__node.html#ga7f79a67df47a08661d622c1ca73571ea":[10,4,10,13],
+"group__pw__node.html#ga8f11f362e3c9cda9d9fba69ed37f9c9b":[10,4,10,25],
+"group__pw__node.html#ga91a6a1a257b75f8a6fd5eb6755447a59":[10,4,10,9],
+"group__pw__node.html#ga98ac2a3a420d51c2afe18a0e79c18efe":[10,4,10,33],
+"group__pw__node.html#ga9d39e0829f4a14185dc242d5c362b9de":[10,4,10,10],
+"group__pw__node.html#gabdc61213ac88ea6daf6141e0130d0430":[10,4,10,32],
+"group__pw__node.html#gac21855a33928eb8c669fb3310e4db5b5":[10,4,10,6],
+"group__pw__node.html#gac3a4cf514e46d1e590ad45fd3e8d7813":[10,4,10,14],
+"group__pw__node.html#gac493839c0b0a1d0b935969f2e990a2df":[10,4,10,31],
+"group__pw__node.html#gae34dde148d3ae268808d68926a8a2da4":[10,4,10,7],
+"group__pw__node.html#gaea23ddf2322c57e3cca4a7d40144bda8":[10,4,10,19],
+"group__pw__node.html#gaf8cda535f0a1e63b1074f859cf650525":[10,4,10,15],
+"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa316510257c8a6afc788c415cc3288ad2":[10,4,10,31,0],
+"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa715c586abce5cbbc09db32145a51e82f":[10,4,10,31,2],
+"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa801ee69d0b0c9d30b12ff89daae9a075":[10,4,10,31,3],
+"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa73a63afebf017a0c0afdea192b1691c":[10,4,10,31,1],
+"group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa9c88f01497f82d9ffc4605dae27e93a":[10,4,10,31,4],
 "group__pw__permission.html":[10,4,11],
-"group__pw__permission.html#ga04ee9df87cc0a2d35ddf5a54a1c2059c":[10,4,11,15],
-"group__pw__permission.html#ga2668b1c9a4b1e4b68fefe81e55d1ee59":[10,4,11,8],
+"group__pw__permission.html#ga04ee9df87cc0a2d35ddf5a54a1c2059c":[10,4,11,19],
+"group__pw__permission.html#ga2668b1c9a4b1e4b68fefe81e55d1ee59":[10,4,11,11],
 "group__pw__permission.html#ga277828556118843e682c652bb1dc9c8e":[10,4,11,4],
 "group__pw__permission.html#ga2a31ac243ad99915377319b663daf426":[10,4,11,2],
+"group__pw__permission.html#ga3211ebb6b1729e3b65910ff1baa00b01":[10,4,11,7],
 "group__pw__permission.html#ga4564637816ca41369b383af05951a3b7":[10,4,11,5],
-"group__pw__permission.html#ga50224a8e3d16e9baa4be58183fec502f":[10,4,11,13],
-"group__pw__permission.html#ga5dca3f2e9a9b71cc78525893eb80355b":[10,4,11,10],
-"group__pw__permission.html#ga77df16320c3bb338666f55b2b21e6e47":[10,4,11,6],
+"group__pw__permission.html#ga50224a8e3d16e9baa4be58183fec502f":[10,4,11,17],
+"group__pw__permission.html#ga5b4b94428c9a8da22ec1e6c3b131a287":[10,4,11,6],
+"group__pw__permission.html#ga5dca3f2e9a9b71cc78525893eb80355b":[10,4,11,13],
+"group__pw__permission.html#ga77df16320c3bb338666f55b2b21e6e47":[10,4,11,8],
+"group__pw__permission.html#ga7aaa8456790d227b44cf625d6d2be621":[10,4,11,15],
+"group__pw__permission.html#ga90f55ec54de28c368c47c6acf7a3f17f":[10,4,11,10],
 "group__pw__permission.html#ga97d33a5e044ee126fd9991b8c70424aa":[10,4,11,3],
-"group__pw__permission.html#ga9f4fda4d9b16f0595986e2d63265fb63":[10,4,11,7],
-"group__pw__permission.html#gaa61804de7cf6003defd8b26ef488ce56":[10,4,11,9],
-"group__pw__permission.html#gaa6b729cf828ec6417f5ba997560fda2b":[10,4,11,14],
-"group__pw__permission.html#gab3c2f31e9ed5b2578d2d86b32a3b7103":[10,4,11,12],
-"group__pw__permission.html#gadea4630c0fbf61f2c42de3339c81abe2":[10,4,11,11],
-"group__pw__permission.html#gaff0a46d4bd012b8d421e848637d64f30":[10,4,11,16],
+"group__pw__permission.html#ga9f4fda4d9b16f0595986e2d63265fb63":[10,4,11,9],
+"group__pw__permission.html#gaa61804de7cf6003defd8b26ef488ce56":[10,4,11,12],
+"group__pw__permission.html#gaa6b729cf828ec6417f5ba997560fda2b":[10,4,11,18],
+"group__pw__permission.html#gab3c2f31e9ed5b2578d2d86b32a3b7103":[10,4,11,16],
+"group__pw__permission.html#gadea4630c0fbf61f2c42de3339c81abe2":[10,4,11,14],
+"group__pw__permission.html#gaff0a46d4bd012b8d421e848637d64f30":[10,4,11,20],
 "group__pw__pipewire.html":[10,4,0],
 "group__pw__pipewire.html#ga06c879b2d800579f4724109054368d99":[10,4,0,1],
 "group__pw__pipewire.html#ga0a42d8f153fc58df733f74e5bf9af251":[10,4,0,14],
@@ -64,43 +85,45 @@ var NAVTREEINDEX4 =
 "group__pw__pipewire.html#gafb27fefe2f3d0620f973c2c76ae3ba8b":[10,4,0,8],
 "group__pw__port.html":[10,4,12],
 "group__pw__port.html#ga08be9849ba07abfd630fcc2b9094e132":[10,4,12,5],
-"group__pw__port.html#ga0a2b3393a17045c7f8a6ff004c8c7f33":[10,4,12,22],
-"group__pw__port.html#ga0f310d02527226da27151627692f999b":[10,4,12,13],
-"group__pw__port.html#ga10cfbc658d844b76a5d3f3528cd2f345":[10,4,12,26],
-"group__pw__port.html#ga1ed9c2e11f128b205fa467a2c0f19fe1":[10,4,12,19],
-"group__pw__port.html#ga2d08d6e2358afc05ca212a0258fb6a26":[10,4,12,16],
-"group__pw__port.html#ga32a9f01e1dde49d9c5b6f64efe7af6e5":[10,4,12,6],
-"group__pw__port.html#ga3e912fde083fd69eca50d503c041eabb":[10,4,12,15],
-"group__pw__port.html#ga5c505757aec81210eabf84b1f9593e70":[10,4,12,17],
-"group__pw__port.html#ga65cece0b739dc2a020a9ded0b26a22a3":[10,4,12,20],
-"group__pw__port.html#ga6ab4af1a18861478a1a9c24f3f59ea79":[10,4,12,29],
-"group__pw__port.html#ga6e316525982a94659dfd8b86d9090c02":[10,4,12,11],
-"group__pw__port.html#ga7458b44dfe9ccfb564276d814a49e94a":[10,4,12,21],
-"group__pw__port.html#ga866d33374688faec738124490db2877e":[10,4,12,25],
-"group__pw__port.html#ga95a863ccc61e0293ae494345bbd51e19":[10,4,12,27],
-"group__pw__port.html#ga9ca65febfd5440fa24c17ae89da5c0bd":[10,4,12,14],
-"group__pw__port.html#gab2082f9bafca5d7d9ff6c53fb3431823":[10,4,12,7],
-"group__pw__port.html#gac245481d75b73061398575ed44ab3e07":[10,4,12,9],
-"group__pw__port.html#gac5541bb77b42b3e6d41d4ee9b4c06b6f":[10,4,12,23],
-"group__pw__port.html#gac556c0b1548946709e9e99daa8b52b1b":[10,4,12,10],
-"group__pw__port.html#gac8fe785592185f71666d2d03903cc367":[10,4,12,8],
-"group__pw__port.html#gad14c54cfcc288a9b8b8f01fe54a86a5d":[10,4,12,24],
-"group__pw__port.html#gada3484ae34475c97571c091b7494d7b3":[10,4,12,18],
-"group__pw__port.html#gaf355e07f1fb54c06af8e1040c47bd1c3":[10,4,12,12],
-"group__pw__port.html#gafaf94d5ec6fb0f925c2f70a34b8ed190":[10,4,12,28],
+"group__pw__port.html#ga0a2b3393a17045c7f8a6ff004c8c7f33":[10,4,12,23],
+"group__pw__port.html#ga0f310d02527226da27151627692f999b":[10,4,12,14],
+"group__pw__port.html#ga10cfbc658d844b76a5d3f3528cd2f345":[10,4,12,27],
+"group__pw__port.html#ga1ed9c2e11f128b205fa467a2c0f19fe1":[10,4,12,20],
+"group__pw__port.html#ga2d08d6e2358afc05ca212a0258fb6a26":[10,4,12,17],
+"group__pw__port.html#ga32a9f01e1dde49d9c5b6f64efe7af6e5":[10,4,12,7],
+"group__pw__port.html#ga3e912fde083fd69eca50d503c041eabb":[10,4,12,16],
+"group__pw__port.html#ga58805afcc510a5167b97851c8e36326b":[10,4,12,6],
+"group__pw__port.html#ga5c505757aec81210eabf84b1f9593e70":[10,4,12,18],
+"group__pw__port.html#ga65cece0b739dc2a020a9ded0b26a22a3":[10,4,12,21],
+"group__pw__port.html#ga6ab4af1a18861478a1a9c24f3f59ea79":[10,4,12,30],
+"group__pw__port.html#ga6e316525982a94659dfd8b86d9090c02":[10,4,12,12],
+"group__pw__port.html#ga7458b44dfe9ccfb564276d814a49e94a":[10,4,12,22],
+"group__pw__port.html#ga866d33374688faec738124490db2877e":[10,4,12,26],
+"group__pw__port.html#ga95a863ccc61e0293ae494345bbd51e19":[10,4,12,28],
+"group__pw__port.html#ga9ca65febfd5440fa24c17ae89da5c0bd":[10,4,12,15],
+"group__pw__port.html#gab2082f9bafca5d7d9ff6c53fb3431823":[10,4,12,8],
+"group__pw__port.html#gac245481d75b73061398575ed44ab3e07":[10,4,12,10],
+"group__pw__port.html#gac5541bb77b42b3e6d41d4ee9b4c06b6f":[10,4,12,24],
+"group__pw__port.html#gac556c0b1548946709e9e99daa8b52b1b":[10,4,12,11],
+"group__pw__port.html#gac8fe785592185f71666d2d03903cc367":[10,4,12,9],
+"group__pw__port.html#gad14c54cfcc288a9b8b8f01fe54a86a5d":[10,4,12,25],
+"group__pw__port.html#gada3484ae34475c97571c091b7494d7b3":[10,4,12,19],
+"group__pw__port.html#gaf355e07f1fb54c06af8e1040c47bd1c3":[10,4,12,13],
+"group__pw__port.html#gafaf94d5ec6fb0f925c2f70a34b8ed190":[10,4,12,29],
 "group__pw__profiler.html":[10,7,2],
-"group__pw__profiler.html#ga07a9df46d368a90b9917e01c186a820f":[10,7,2,10],
-"group__pw__profiler.html#ga1810f152594c69f1955dd300585cf12a":[10,7,2,12],
-"group__pw__profiler.html#ga1f3257ff0903e9d284048f1d119c00eb":[10,7,2,11],
+"group__pw__profiler.html#ga07a9df46d368a90b9917e01c186a820f":[10,7,2,11],
+"group__pw__profiler.html#ga1810f152594c69f1955dd300585cf12a":[10,7,2,13],
+"group__pw__profiler.html#ga1f3257ff0903e9d284048f1d119c00eb":[10,7,2,12],
 "group__pw__profiler.html#ga2270ff65dd05ec8d44b575d345b34ef7":[10,7,2,4],
-"group__pw__profiler.html#ga24d59364fcf4c282135018a9d4515174":[10,7,2,7],
-"group__pw__profiler.html#ga3a9ba0d4647580d079d96ff5163eabe3":[10,7,2,15],
-"group__pw__profiler.html#ga8269aa7abfa3353f2c877b7ec85be6e9":[10,7,2,9],
-"group__pw__profiler.html#ga95f26236f843ad4afc3de455b45cbcc3":[10,7,2,13],
+"group__pw__profiler.html#ga24d59364fcf4c282135018a9d4515174":[10,7,2,8],
+"group__pw__profiler.html#ga3a9ba0d4647580d079d96ff5163eabe3":[10,7,2,16],
+"group__pw__profiler.html#ga8269aa7abfa3353f2c877b7ec85be6e9":[10,7,2,10],
+"group__pw__profiler.html#ga95f26236f843ad4afc3de455b45cbcc3":[10,7,2,14],
 "group__pw__profiler.html#gaa67b89b0b81bd0f644e9dc815910a5a6":[10,7,2,5],
+"group__pw__profiler.html#gac0ad872ccb3327d007c9e71f2210982d":[10,7,2,7],
 "group__pw__profiler.html#gadce3d202b44c713a464705f5d1651231":[10,7,2,6],
-"group__pw__profiler.html#gaf01a5556e210e625e2acbda238290083":[10,7,2,8],
-"group__pw__profiler.html#gafc2a6db1575319ddccac1e4f6a8c17d9":[10,7,2,14],
+"group__pw__profiler.html#gaf01a5556e210e625e2acbda238290083":[10,7,2,9],
+"group__pw__profiler.html#gafc2a6db1575319ddccac1e4f6a8c17d9":[10,7,2,15],
 "group__pw__properties.html":[10,6,6],
 "group__pw__properties.html#ga020d2bd083e845bbfa3d2366d8c7ffec":[10,6,6,18],
 "group__pw__properties.html#ga1b4b83cd7ff56bdcabc3419f3a40eb95":[10,6,6,7],
@@ -226,28 +249,5 @@ var NAVTREEINDEX4 =
 "group__pw__resource.html#ga5f5b343c88d5274a6702755a6452cb40":[10,5,14,14],
 "group__pw__resource.html#ga6000827e0dc8637b0538f75800c0f581":[10,5,14,28],
 "group__pw__resource.html#ga6006f7393419cb5c874398f2954ac1b4":[10,5,14,22],
-"group__pw__resource.html#ga61e286d92a2f528ebe48cb1436ac4eba":[10,5,14,5],
-"group__pw__resource.html#ga69d44482d7bb5e6fbb95a66ccce009ed":[10,5,14,24],
-"group__pw__resource.html#ga8baec43db135c6f71cf26b7b3e500361":[10,5,14,10],
-"group__pw__resource.html#ga9135836c3f3a0860261aee85ae6dcc3c":[10,5,14,27],
-"group__pw__resource.html#ga98bbacb715f5469dcc14a071d14b3883":[10,5,14,23],
-"group__pw__resource.html#ga9edff924e88ea8ae7d0b74065ad7415a":[10,5,14,18],
-"group__pw__resource.html#gaa2d8c1bd7008acbd8fe30e47e6c08d3f":[10,5,14,17],
-"group__pw__resource.html#gaa4360011ae8b18da2fb24de682cfbc61":[10,5,14,19],
-"group__pw__resource.html#gaadff480a3e38ec195e07567c1e46ab54":[10,5,14,3],
-"group__pw__resource.html#gab9e159d75b7efe39bd53b64055244092":[10,5,14,8],
-"group__pw__resource.html#gae08cdf7d997595185d3e7ff0235a6305":[10,5,14,26],
-"group__pw__resource.html#gaeb9ac77ab0c2ad96099396c64a4ffb92":[10,5,14,7],
-"group__pw__resource.html#gaf3044f96f645e97035b87d3b37d3e017":[10,5,14,21],
-"group__pw__resource.html#gaf8fe4859dd6826d5eb6c7e28f5519215":[10,5,14,11],
-"group__pw__resource.html#gafc12935cd9ee93e992cae1e2910e6f04":[10,5,14,15],
-"group__pw__resource.html#gafc89e299d5a8ee7eb725e6b4994b61a6":[10,5,14,13],
-"group__pw__session__manager.html":[10,7,4],
-"group__pw__session__manager.html#ga00906166f757acda0920e5e94e7a0002":[10,7,4,90],
-"group__pw__session__manager.html#ga013bd15be1036877f208d4ae5adf3efa":[10,7,4,94],
-"group__pw__session__manager.html#ga0389e5a5379465102059b7bc76359fc4":[10,7,4,149],
-"group__pw__session__manager.html#ga061b1a63dcbc70226273140b6191b19c":[10,7,4,51],
-"group__pw__session__manager.html#ga08be0f2d923af19e43e0a292d0bd351d":[10,7,4,135],
-"group__pw__session__manager.html#ga0a0e349bd0024457457e6f56dc0fbeb3":[10,7,4,77],
-"group__pw__session__manager.html#ga0a2fbf1e9c6493db2e61e629647dda82":[10,7,4,78]
+"group__pw__resource.html#ga61e286d92a2f528ebe48cb1436ac4eba":[10,5,14,5]
 };
